#------------------------------------------------------------------------------
# @(#) config-ericsson-msc-r12/vstart/UserConfig.pm config-ericsson-msc-r12_r3.3.0.5:cset.003141:11:11@(#)
#------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Ericsson R12
#
# Updated 17/07/2007 for Ericsson R12 NSS and MSC Compatibility
# 

package UserConfig;

@ISA = qw(Exporter);
@EXPORT = qw(file_type postparser_config);

#use diagnostics;
use strict;
use Exporter ();

my @file_type =(

#------------------------------------------------------------------------------
# Add filetype name expressions here
#------------------------------------------------------------------------------
# Use TRAR for block size 1088 and TRAR2 for block size 1100
# SAW 20OOct1998
    {NAME => ".*TRARFILE.*",    TYPE => "TRAR"},
    {NAME => ".*TRDIPFILE.*",   TYPE => "TRDIP"},
    {NAME => ".*",              TYPE => "STFIOP"},
#------------------------------------------------------------------------------

);

#------------------------------------------------------------------------------

my @rules = (
#------------------------------------------------------------------------------
# Modify/Add rules here
#------------------------------------------------------------------------------

# 05/04/05 Introduced
# Join C7SL1 and C7SL2 blocks
{   
    'RULE_TYPE' => 'JOIN',
    'RULE_DESC' => 'Join C7SL1 and C7SL2 blocks to produce C7SL',
    'INPUT_FILE_DESCRIPTION' => [
        "C7SL1-#-(.*)-#-.+-#-I.pif",
        "C7SL2-#-(.*)-#-.+-#-I.pif"
    ],
    # Correction done based on SRS 38248
    # - Added this entry caused the block C7SL failed 
    #   to be produced. Therefore the 'Original expression is reuse'. 
    #'INPUT_FILE_DESCRIPTION' => [
    #    'C7SL1-(.*)#[/w|-]*#-I.pif',
    #    'C7SL2-(.*)#[/w|-]*#-I.pif'
    #],
    'OUTPUT_BLOCK_NAME' => "C7SL",
    'COUNTERS_TO_JOIN_ON' => ['NODEID' , "OBJ_ID" ],
    'OUTPUT_FILENAME_START' => "S7LINK_NSS",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "OBJ_ID", "START_TIME", "START_DATE"
    ],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# 05/04/05 Introduced
# Join C7SLSET and C7ADJSLP block to produce C7SLSET
#{   
#    'RULE_TYPE' => 'JOIN',
#    'RULE_DESC' => 'Join C7SLSET and C7ADJSLP block to produce C7SLSET',
#    'INPUT_FILE_DESCRIPTION' => [
#        "C7SLSET-#-(.*)-#-.+-#-I.pif",
#        "C7ADJSLP-#-(.*)-#-.+-#-I.pif"
#    ],
#    'OUTPUT_BLOCK_NAME' => "C7SLSET",
#    'COUNTERS_TO_JOIN_ON' => ['NODEID' , "OBJ_ID" ],
#    'OUTPUT_FILENAME_START' => "C7SLSET_NSS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "OBJ_ID", "START_TIME", "START_DATE"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R12 - Rules to produce the C7SPNT block are not required
# 05/04/05 Introduced
# C7SPNT mappings
#{
#    'RULE_TYPE' => 'JOIN',
#    'RULE_DESC' => "C7SPNT mappings",
#    'INPUT_FILE_DESCRIPTION' => [
#        "C7OPC-#-(.*)-#-.+-#-I.pif",
#        "C7DPC-#-(.*)-#-.+-#-I.pif", 
#        "C7ADJSLP-#-(.*)-#-.+-#-I.pif"
#    ],
#    'OUTPUT_BLOCK_NAME' => "C7SPNT",
#    'COUNTERS_TO_JOIN_ON' => ['NODEID' , "OBJ_ID" ],
#    'OUTPUT_FILENAME_START' => "C7SPNT_NSS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "OBJ_ID", "START_TIME", "START_DATE"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R12 - Produce the block components making up the C7SPNT block instead
# backup lif generation
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R10",
    'INPUT_FILE_DESCRIPTION' => [
        "C7OPC-#-(.*)-#-I.pif", 
        "C7DPC-#-(.*)-#-I.pif", 
        "C7ADJSLP-#-(.*)-#-I.pif"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

#------------------------------------------------------------------------------
# ROUTE 
#------------------------------------------------------------------------------
# Support Call 43553: Added new rules to process outgoing MAIN routes
# that are not suffixed with O
# ROUTELOSS - Separate outgoing routes not suffixed with O
{
    'RULE_TYPE' => 'DATALINE_WHERE',
    'RULE_DESC' => "Separate out MAIN routes not suffixed with I or O",
    'INPUT_FILE_DESCRIPTION' => [ "ROUTELOSS-#-.*-#-I.pif" ],
    'COUNTER_NAMES' => [
        {
            'COUNTER_NAME' => "ROUTE_NAME",
            'KEEP_WHERE'   => ['^(MAIN\+\d)$'],
        },
    ],
    'PRODUCE_PIF' => "True",
    'FILENAME_ADDITION' => "MAIN",
},

#{
#    'RULE_TYPE' =>                'DATALINE_WHERE',
#    'RULE_DESC' =>                "Separate out MAIN routes not suffixed with I or O",
#    'INPUT_FILE_DESCRIPTION' =>   [ "ROUTELOSS-#-.*-#-I.pif" ],
#    'COUNTER_NAME' =>             "ROUTE_NAME",
#    'KEEP_WHERE' =>               ['(\w+)+'],
#    'PRODUCE_PIF' =>              "True",
#    'FILENAME_ADDITION' =>        "MAIN",
#},

# ROUTELOSS - Use CVAL_MANIP rule to suffix MAIN routes with O
{
    'RULE_TYPE' => 'CVAL_MANIP',
    'RULE_DESC' => 'Change MAIN route names to append O',
    'INPUT_FILE_DESCRIPTION' => ["ROUTELOSS-#-(.*)-#-MAIN-#-DW.pif"],
    'PRODUCE_PIF' => "True",
    'CNAME_MANIP' => "ROUTE_NAME",
    'MATCH' => ['^(MAIN\+\d)$'],
    'PATTERN' => ['$1O'],
},

#------------------------------------------------------------------------------
# ROUTELOSS - SPLIT incoming routes
#------------------------------------------------------------------------------
#{
#    'RULE_TYPE' => 'SPLIT_IO',
#    'RULE_DESC' => 'Splitting out the incoming routes',
#    'COUNTER_TO_DETERMINE_IO' => "ROUTE_NAME",
#    'SUFFIX_TO_USE' => "I",
#    'INPUT_FILE_DESCRIPTION' => [ "ROUTELOSS-#-.*-#-I.pif"],
#    'REDUNDANT_DATA_COUNTERS' => ["FILLER"],
#    'COUNTER_NAMES_NOT_TO_CHANGE' => [
#        "SUM_BDEVS", "NO_ACCUMULATIONS_TRAFFL", "NO_ACCUMULATIONS_BLOCKL"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#{
#    'RULE_TYPE' => 'SPLIT_IO',
#    'RULE_DESC' => 'Splitting out the incoming routes',
#    'COUNTER_TO_DETERMINE_IO' => "ROUTE_NAME",
#    'SUFFIX_TO_USE' => "I",
#    'INPUT_FILE_DESCRIPTION' => ["ROUTELOSS-#-.*-#-I.pif"],
#    'REDUNDANT_DATA_COUNTERS' => ["FILLER"],
#    'COUNTER_NAMES_NOT_TO_CHANGE' => [
#        "NO_ACCUMULATIONS_TRAFFL", "NO_ACCUMULATIONS_BLOCKL"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#------------------------------------------------------------------------------
# ROUTELOSS - SPLIT outgoing routes
#------------------------------------------------------------------------------
# Support Call 43553: Modified to include files from DW and CM rules above
#{
#    'RULE_TYPE' => 'SPLIT_IO',
#    'RULE_DESC' => 'Splitting out the outgoing routes',
#    'COUNTER_TO_DETERMINE_IO' => "ROUTE_NAME",
#    'SUFFIX_TO_USE' => "O",
#    'INPUT_FILE_DESCRIPTION' => [
#        "ROUTELOSS-#-.*-#-I.pif",
#        "ROUTELOSS-#-.*-#-I-#-MAIN-#-DW-#-CM.pif"
#    ],
#    'REDUNDANT_DATA_COUNTERS' => ["FILLER"],
#    'COUNTER_NAMES_NOT_TO_CHANGE' => [
#        "SUM_BDEVS", "NO_ACCUMULATIONS_TRAFFL", "NO_ACCUMULATIONS_BLOCKL"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#{
#    'RULE_TYPE' => 'SPLIT_IO',
#    'RULE_DESC' => 'Splitting out the outgoing routes',
#    'COUNTER_TO_DETERMINE_IO' => "ROUTE_NAME",
#    'SUFFIX_TO_USE' => "O",
#    'INPUT_FILE_DESCRIPTION' => [
#        "ROUTELOSS-#-.*-#-I.pif",
#        "ROUTELOSS-#-.*-#-I-#-MAIN-#-DW-#-CM.pif"
#    ],
#    'REDUNDANT_DATA_COUNTERS' => ["FILLER"],
#    'COUNTER_NAMES_NOT_TO_CHANGE' => [
#        "NO_ACCUMULATIONS_TRAFFL", "NO_ACCUMULATIONS_BLOCKL"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#------------------------------------------------------------------------------
# ROUTELOSS - JOIN
#------------------------------------------------------------------------------
#{
#    'RULE_TYPE' => 'JOIN',
#    'INPUT_FILE_DESCRIPTION' => [
#        "ROUTELOSS-#-(.*)-#-SPI.pif",
#        "ROUTELOSS-#-(.*)-#-SPO.pif",
##        "ROUTELOSS-#-(.*)-#-MAIN-#-DW-#-CM-#-SPO.pif",
#    ],
#    'OUTPUT_BLOCK_NAME' => "ROUTELOSS",
#    'COUNTERS_TO_JOIN_ON' => ["ROUTE_NAME"],
#    'OUTPUT_FILENAME_START' => "ROUTELOSS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "START_TIME", "START_DATE"
#    ],
#    'NON_APPLICABLE_HEADER_COUNTERS' => [
#        "SUM_BDEVS", "FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
#    ],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_TYPE_ID", "FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' => "True",
#},

{
    'RULE_TYPE' => 'JOIN',
    'INPUT_FILE_DESCRIPTION' => [
        "ROUTELOSS-#-(.*)-#-SPI.pif",
        "ROUTELOSS-#-(.*)-#-MAIN-#-DW-#-CM-#-SPSO.pif",
        "ROUTELOSS-#-(.*)-#-SPO.pif"
    ],
    'OUTPUT_BLOCK_NAME' => "ROUTELOSS",
    'COUNTERS_TO_JOIN_ON' => ["ROUTE_NAME"],
    'OUTPUT_FILENAME_START' => "ROUTELOSS",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "START_TIME", "START_DATE"
    ],
    'NON_APPLICABLE_HEADER_COUNTERS' => [
        "SUM_BDEVS", "FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
    ],
    'REDUNDANT_DATA_COUNTERS' => [
        "OBJ_TYPE_ID", "FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
    ],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
    'PRODUCE_PIF' => "True",
},

# Determine route direction in recombined ROUTELOSS: mapped to ROUTE table.
# Support Call ID 43513: Enhanced to check for asynchronous bothway routes.
#{
#    'RULE_TYPE' =>                 'ROUTE_DIRECTION',
#    'RULE_DESC' =>                 "Determine route direction in ROUTELOSS",
#    'INPUT_FILE_DESCRIPTION' =>    [ "^ROUTELOSS-#-(.*)-#-J.pif" ],
#    'COUNTER_TO_SEARCH_ON_FOR_IN' =>  "NO_BIDS_I",
#    'COUNTER_TO_SEARCH_ON_FOR_OUT' => "NO_BIDS_O",
#    'CODE_FOR_INCOMING' =>      'I',
#    'CODE_FOR_OUTGOING' =>      'O',
#    'CODE_FOR_BOTH_DIRECTIONS' =>  'B',
#    'OUTPUT_COUNTER_NAME' =>    "ROUTE_DIR",
#    'ROUTE_NAME_COUNTER' => "ROUTE_DIR",
#    'INCOMING_CIRCUIT_NO_COUNTER' => "ROUTE_DIR",
#    'OUTGOING_CIRCUIT_NO_COUNTER' => "ROUTE_DIR",
#    'NEW_COUNTER_VALUE_IN' =>    "NO_DEVICES_I",
#    'NEW_COUNTER_VALUE_OUT' =>   "NO_DEVICES_O",
#    'ADD_NEW_COUNTER' =>    "NO_DEVICES",
#    'PRODUCE_PIF' =>         "True",
# },

#{ 
#    'RULE_TYPE' => 'ROUTE_DIRECTION',
#    'RULE_DESC' => "Determine route direction in ROUTELOSS",
#    'RULE_DESCRIPTION' => "Determine route direction in ROUTELOSS",
#    'INPUT_FILE_DESCRIPTION' => [ "^ROUTELOSS-#-(.*)-#-J.pif" ],
#    'COUNTER_TO_SEARCH_ON_FOR_IN' => "NO_BIDS_I",
#    'COUNTER_TO_SEARCH_ON_FOR_OUT' => "NO_BIDS_O",
#    'CODE_FOR_INCOMING' => 'I',
#    'CODE_FOR_OUTGOING' => 'O',
#    'CODE_FOR_BOTH_DIRECTIONS' => 'B',
#    'OUTPUT_COUNTER_NAME' => "ROUTE_DIR",
#    'ROUTE_NAME_COUNTER' => "ROUTE_NAME",
#    'INCOMING_CIRCUIT_NO_COUNTER' => "NO_DEVICES_I",
#    'OUTGOING_CIRCUIT_NO_COUNTER' => "NO_DEVICES_O",
#    'PRODUCE_PIF' => "True",
#},

# Output ROUTELOSS data to NSS directory
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson 9.0",
    'INPUT_FILE_DESCRIPTION' => [ "ROUTELOSS-#-(.*)-#-J-#-R.*.pif" ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Ericsson 9.0",
#    'INPUT_FILE_DESCRIPTION' => [ "ROUTELOSS-#-(.*)-#-1-#-J-#-R.*.pif" ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# Added new fields, previously used in the NPR R9.1 parser.
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson 9.0",
    'INPUT_FILE_DESCRIPTION' => [
        "TRAFFTYPE.*.pif", 
        #"MTRAFTYPE.*.pif",
        #"SUPPLSERV.*.pif", 
        "TRAFFDEST.*.pif", 
        "C7RTSET.*.pif", 
        "LOCAREAST.*.pif",
        "TRAPEVENT.*.pif", 
        "TRDIP.*.pif",
        "C7DPCSIO.*.pif",
        "C7OPCSIO.*.pif"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'REDUNDANT_DATA_COUNTERS' => [
        "OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
    ],
},

{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson 9.0",
    'INPUT_FILE_DESCRIPTION' => ["CHASSIGNT.*.pif"] ,
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'REDUNDANT_DATA_COUNTERS' => [
        "OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS","OBJ_ID"
    ],
},

# 01/02/05 Removed as no need to segregate foreign HLRs
#------------------------------------------------------------------------------
# HLRSTAT: remove home HLR IDs.  This will then be aggregated.  Mapped to
# MSC_PAGE table, together with HLRSTAT (all HLRs), PAGING, UPDLOCAT object
# types.
#{ 
#    'RULE_TYPE' => 'DATALINE_WHERE',
#    'RULE_DESC' => "Remove home HLR IDs in HLRSTAT",
#    'INPUT_FILE_DESCRIPTION' => [ "HLRSTAT-#-(.*)-#-I.pif" ],
#    'COUNTER_NAMES'  => [
#        {
#            'COUNTER_NAME'  => 'OBJ_ID',
#            'REMOVE_WHERE' => [ "432486*" ],
#        },
#    ],
#  
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS", "OBJ_TYPE_ID", "OBJ_GROUP_NO", "OBJ_TYPE_FAULT_CODE",
#        "NO_COUNTERS", "FILLER"
#    ],
#    'PRODUCE_PIF' => "True",
#},

# 01/02/05 Same as above 
# Aggregate HLRSTAT following removal of home HLRs: mapped to MSC_PAGE table,
# together with HLRSTAT (all HLRs), PAGING, UPDLOCAT object types.
#{ 
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_DESC' => "Accumulate HLRSTAT (foreign HLRs)",
#    'INPUT_FILE_DESCRIPTION' => [ "HLRSTAT-#-(.*)-#-I-#-DW.pif" ],
#    'COUNTERS_TO_SORT_ON' => [ "NODEID", "START_DATE", "START_TIME" ],
#    'NON_ADDITIVE_COUNTERS' => [ "OBJ_ID" ],
#    'OUTPUT_BLOCK_NAME' => "HLRSTAT_FOREIGN",
#    'APPEND_STR' => "_FOREIGN",
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS", "OBJ_TYPE_ID", "OBJ_GROUP_NO", "OBJ_TYPE_FAULT_CODE",
#        "NO_COUNTERS", "FILLER", "OBJ_ID"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#HLRSTAT-#--#-10Jan2005-#-LSB50___61_44_04_08_E5_-#-C-#-16:30:00-#-6-#-I.pif
# Aggregate HLRSTAT for all HLRs: mapped to MSC_PAGE table, together with
# HLRSTAT (foreign HLRs), PAGING, UPDLOCAT object types.
{ 
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => "Accumulate HLRSTAT (all HLRs)",
    'INPUT_FILE_DESCRIPTION' => [ "HLRSTAT-#-(.*)-#-I.pif" ],
    'COUNTERS_TO_SORT_ON' => [
        "NODEID", "START_DATE", "START_TIME"
    ],
    'NON_ADDITIVE_COUNTERS' => [ "OBJ_ID" ],
    'OUTPUT_BLOCK_NAME' => "HLRSTAT_MSC_AGGR",
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS", "OBJ_TYPE_ID", "OBJ_GROUP_NO", "OBJ_TYPE_FAULT_CODE",
        "NO_COUNTERS", "FILLER", "OBJ_ID", "HLRSTAT_MSC_AGGR_NUM_IN_SUM"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# Introduced
#------------------------------------------------------------------------------
# MSCPAGE - JOIN
# Combine HLRSTAT (all HLRs), HLRSTAT (foreign HLRs), PAGING, UPDLOCAT.  They
# are mapped to the MSC_PAGE table.
# There is no object ID to join on, so a dummy counter name is used (all files
# to be joined by this rule will have just one data line each).
#
# Bug #57117/57114 - MSCPAGE not required in R12. Remove in next release.
#{
#    'RULE_TYPE' => 'JOIN',
#    'INPUT_FILE_DESCRIPTION' => [
#        "PAGING-#-(.*)-#-.+-#-I.pif",
#        "UPDLOCAT-#-(.*)-#-.+-#-I.pif",
#        "HLRSTAT-#-(.*)-#-.+-#-I-#-HLRSTAT_MSC_AGGR-#-A.pif",
##        "HLRSTAT-#-(.*)-#-.+-#-I-#-DW-#-HLRSTAT_FOREIGN-#-A.pif",
#    ],
#    'OUTPUT_BLOCK_NAME' => "MSCPAGE",
#    'COUNTERS_TO_JOIN_ON' => ['NODEID'],
#    'OUTPUT_FILENAME_START' => "MSCPAGE_NSS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "START_TIME", "START_DATE"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# No longer needed 07/04/05
# Output MSC_PAGE data to NSS directory
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Ericsson 9.0",
#    'INPUT_FILE_DESCRIPTION' => [ "MSCPAGE_NSS.*.pif" ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# default lif file generation
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Ericsson R10",
#    'INPUT_FILE_DESCRIPTION' => [
#        "PAGING-#-(.*)-#-.+-#-I.pif",
#        "UPDLOCAT-#-(.*)-#-.+-#-I.pif",
#        "HLRSTAT-#-(.*)-#-.+-#-I-#-HLRSTAT_MSC_AGGR-#-A.pif",
##        "HLRSTAT-#-(.*)-#-.+-#-I-#-DW-#-HLRSTAT_FOREIGN-#-A.pif"
#    ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# removed Aggr, I don't think it is required in PM.
#------------------------------------------------------------------------------
# MSCHO - Aggregate and Join
# MSC_HO Accumulate
#{
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_DESC' => 'Aggregate MSC Handovers',
#    'RULE_DESC' => 'ACCUM_MSCHO',
#    'INPUT_FILE_DESCRIPTION' => [ "NBRMSCLST-#-(.*)-#-I.pif"],
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_BLOCK_NAME' => "AGGR",
#    'COUNTERS_TO_SORT_ON' => ["OBJ_TYPE_ID"],
#    'NON_ADDITIVE_COUNTERS' => ["OBJ_TYPE_ID","OBJ_ID"],
#},

# R12 - Rules to produce the MSCHO block are not required
#
# 05/04/05
# MSC_HO Join
#{   
#    'RULE_TYPE' => 'JOIN',
#    'INPUT_FILE_DESCRIPTION' => [
#        "HNDOVER-#-(.*)-#-.+-#-I.pif",
#        "NBRMSCLST-#-(.*)-#-.+-#-I-#-AGGR-#-A.pif"
#    ],
#    'OUTPUT_BLOCK_NAME' => "MSCHO",
#    'COUNTERS_TO_JOIN_ON' => ['NODEID'],
#    'OUTPUT_FILENAME_START' => "MSCHO",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "START_TIME", "START_DATE"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' => "True",
#},

# 05/04/05 
# Output MSC_HO data to NSS directory
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "MSCHO P2L Ericsson R10",
#    'INPUT_FILE_DESCRIPTION' => [ "MSCHO.*.pif" ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# 05/04/05 Also need to output raw NBRMSCLST for raw neighbour tables.
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "NBRMSCLST P2L Ericsson R10",
    'INPUT_FILE_DESCRIPTION' => ["NBRMSCLST-#-(.*)-#-.+-#-I.pif" ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

{
    'RULE_TYPE' => 'CVAL_MANIP',
    'RULE_DESC' => 'Manipulate counter values that contain spaces',
    'INPUT_FILE_DESCRIPTION'=> ['^SERVFEAT-#(.*)-#-I.pif'],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'CNAME_MANIP' => 'OBJ_ID',
    'MATCH' => ['^(\w+\-*\w*)\s+(\w+)'],
    'PATTERN' => ['$1_$2'],
},

#------------------------------------------------------------------------------
# Additional Rules for Ericsson R10.
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R10",
    'INPUT_FILE_DESCRIPTION' => [
        "AAL2PATH.*.pif",
        #"BSCSTAT.*.pif",
        "DTISTAT.*.pif",
        "ECPOOL.*.pif",
        "ISDNEBS.*.pif",
        "ISDNESG.*.pif",
        #"LCSSTAT.*.pif", 
        "LOSSROUTE.*.pif",
        "MAPSIGIWRK.*.pif", 
        "NBRMSCGUH.*.pif", 
        "NBRMSCUGHO.*.pif",
        "OPTFEAT.*.pif",
        "PDCUMTSFLN.*.pif",
        "RELOC.*.pif",
        "RNCSTAT.*.pif",
        "SAE.*.pif",
        "PDPDEF.*.pif", #07 Mar 2006
        "GUHNDOVER.*.pif", #07 Mar 2006  
        "SESSCF.*.pif",
        #"SHAM.*.pif",
        "HNDOVER*.pif", 
        "UGHNDOVER.*.pif",
        "UMTSPOS.*.pif", 
        "SHMSGSERV.*.pif",
        "TRANSFLNO.*.pif",
        "SHIST.*.pif",
        "TRUNKROUTE.*.pif",
        "UMTSPOS.*.pif",
        "UMTSSEC.*.pif",
        # KYTAN - files that were not output before
        "PDPDEF.*.pif",
        #"NAMSUBS.*.pif",
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# Add Dataline where rule to separate the ECNP items
{
    'RULE_TYPE' => 'DATALINE_WHERE',
    'RULE_DESC' => 'Separate the ECNP items',
    'INPUT_FILE_DESCRIPTION' => ["ECNP.*I.pif"],
    'OUTPUT_BLOCK_NAME' => 'ECNPASLR',
    'COUNTER_NAMES'  => [
        {
            'COUNTER_NAME' => 'ECNP',
            'KEEP_WHERE' => ["ASL_R"],
        },
    ],
    'FILENAME_ADDITION' => 'ECNPASLR',
    'REDUNDANT_DATA_COUNTERS' => ["ECNP"],
    'PRODUCE_PIF'  => 'True',
},

{
    'RULE_TYPE' => 'DATALINE_WHERE',
    'RULE_DESC' => 'Separate the ECNP items',
    'INPUT_FILE_DESCRIPTION' => ["ECNP.*I.pif"],
    'OUTPUT_BLOCK_NAME' => 'ECNPASLS',
    'COUNTER_NAMES'  => [
        {
            'COUNTER_NAME' => 'ECNP',
            'KEEP_WHERE' => ["ASL_S"],
        },
    ],
    'FILENAME_ADDITION' => 'ECNPASLS',
    'REDUNDANT_DATA_COUNTERS' => ["ECNP"],
    'PRODUCE_PIF'  => 'True',
},

{
    'RULE_TYPE' => 'DATALINE_WHERE',
    'RULE_DESC' => 'Separate the ECNP items',
    'INPUT_FILE_DESCRIPTION' => ["ECNP.*I.pif"],
    'OUTPUT_BLOCK_NAME' => 'ECNPERL',
    'COUNTER_NAMES'  => [
        {
            'COUNTER_NAME' => 'ECNP',
            'KEEP_WHERE' => ["ERL"],
        },
    ],
    'FILENAME_ADDITION' => 'ECNPERL',
    'REDUNDANT_DATA_COUNTERS' => ["ECNP"],
    'PRODUCE_PIF'  => 'True',
},

{
    'RULE_TYPE' => 'DATALINE_WHERE',
    'RULE_DESC' => 'Separate the ECNP items',
    'INPUT_FILE_DESCRIPTION' => ["ECNP.*I.pif"],
    'OUTPUT_BLOCK_NAME' => 'ECNPPD',
    'COUNTER_NAMES'  => [
        {
            'COUNTER_NAME' => 'ECNP',
            'KEEP_WHERE' => ["PD"],
        },
    ],
    'FILENAME_ADDITION' => 'ECNPPD',
    'REDUNDANT_DATA_COUNTERS' => ["ECNP"],
    'PRODUCE_PIF'  => 'True',
},

# Added this rule to redirect the ECNP files to the correct location.
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Ericsson R10",
#    'INPUT_FILE_DESCRIPTION' => ["ECNP.*DW.pif" ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => 'APPEND the block name to ECNPASLR',
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME' => "ECNPASLR",
    'INPUT_FILE_DESCRIPTION' => [ "ECN.*ECNPASLR-#-DW.pif" ],
    'COUNTERS_TO_SORT_ON' => ["NODEID"],
    'NON_ADDITIVE_COUNTERS' => ["suspectFlag","NVALID"],
    'REDUNDANT_DATA_COUNTERS' => ["suspectFlag","ECNPASLR_NUM_IN_SUM"], 
    'APPEND_STR' => "ASLR",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => 'APPEND the block name to ECNPASLS',
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME' => "ECNPASLS",
    'INPUT_FILE_DESCRIPTION' => [ "ECN.*ECNPASLS-#-DW.pif" ],
    'COUNTERS_TO_SORT_ON' => ["NODEID"],
    'NON_ADDITIVE_COUNTERS' => ["suspectFlag","NVALID"],
    'REDUNDANT_DATA_COUNTERS' => ["suspectFlag","ECNPASLS_NUM_IN_SUM"],
    'APPEND_STR' => "ASLS",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => 'APPEND the block name to ECNPERL',
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME' => "ECNPERL",
    'INPUT_FILE_DESCRIPTION' => [ "ECN.*ECNPERL-#-DW.pif" ],
    'COUNTERS_TO_SORT_ON' => ["NODEID"],
    'NON_ADDITIVE_COUNTERS' => ["suspectFlag","NVALID"],
    'REDUNDANT_DATA_COUNTERS' => ["suspectFlag","ECNPERL_NUM_IN_SUM"],
    'APPEND_STR' => "ERL",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => 'APPEND the block name to ECNPPD',
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME' => "ECNPPD",
    'INPUT_FILE_DESCRIPTION' => [ "ECN.*ECNPPD-#-DW.pif" ],
    'COUNTERS_TO_SORT_ON' => ["NODEID"],
    'NON_ADDITIVE_COUNTERS' => ["suspectFlag","NVALID"],
    'REDUNDANT_DATA_COUNTERS' => ["suspectFlag","ECNPPD_NUM_IN_SUM"],
    'APPEND_STR' => "PD",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => 'Aggregate ECNP',
    'RULE_DESC' => 'ACCUMULATE ECNP',
    'INPUT_FILE_DESCRIPTION' => [ "ECNP-#-(.*)-#-.+-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME' => "ECNP",
    'COUNTERS_TO_SORT_ON' => ["NVALID"],
    'REDUNDANT_DATA_COUNTERS' => ["suspectFlag","ECNP","ECNP_NUM_IN_SUM"], 
    'NON_ADDITIVE_COUNTERS' => ["ECNP","suspectFlag"],
},

# 10/02/05 Added to deail with default value in TRUNKROUTE
#{
#    'RULE_TYPE' => 'DATALINE_WHERE',
#    'RULE_DESC' => 'Handle TRUNKROUTE Default ',
#    'INPUT_FILE_DESCRIPTION' => ["TRUNKROUTE.*.pif"],
#    #'OUTPUT_BLOCK_NAME' => '',
#    'COUNTER_NAMES'  => [
#        {
#            'COUNTER_NAME' => '',
##           'KEEP_WHERE' => [""],
#        },
#    ],
#    'FILENAME_ADDITION' => '',
#    'REDUNDANT_DATA_COUNTERS' => [""],
#    'PRODUCE_PIF'  => 'True',
#},

##############################################################
#           All HLR rules will be dealt with here            #
##############################################################

# Output the HLRMAP data before it is altered
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "PIF_2_OUTPUT for HLRMAP and PLMNSUB Ericsson R10",
    'INPUT_FILE_DESCRIPTION' => ["HLRMAP.*-#-I.pif", "PLMNSUB.*-#-I.pif" ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R12 - The rules to produce the HLR block are not required for MSC

# Accumulate HLRMAP across NODEID
#{
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_DESC' => 'Accumulate HLRMAP across NODEID',
#    'INPUT_FILE_DESCRIPTION' => [ "HLRMAP.*-#-I.pif"],
#    'OUTPUT_BLOCK_NAME' => "HLRMAP",
#    'COUNTERS_TO_SORT_ON' => ["NODEID"],
#    'NON_ADDITIVE_COUNTERS' => ["OBJ_ID"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID", "suspectFlag", "OBJ_TYPE_FAULT_CODE", "NO_OBJ_RECORDS",
#        "NO_COUNTERS", "OBJ_TYPE_ID", "OBJ_GROUP_NO"
#    ],
#    'PRODUCE_PIF' => "True",
#},

#------------------------------------------------------------------------------
# LPLMN removal of home plmn id & invalid obj_id
# Filename_addition NOHOME removed as it is redundant.
#{
#    'RULE_TYPE' => 'DATALINE_WHERE',
#    'RULE_DESC' => 'Remove home plmn & invalid obj_id',
#    'INPUT_FILE_DESCRIPTION' => [ "PLMNSUB.*-#-I.pif"],
#    'COUNTER_NAMES'  => [
#        {
#            'COUNTER_NAME'  => 'OBJ_ID',
#            'KEEP_WHERE'  => [ "[A-Za-z0-9]-[A-Za-z0-9]" ],
#            'REMOVE_WHERE' => ["0000000000000000"],
#        },
#    ],
#    'OBJ_ID_TO_DELETE' => ["0000000000000000"],
#    'REDUNDANT_DATA_COUNTERS' => ["NO_OBJ_RECORDS", "OBJ_TYPE_ID", "NO_COUNTERS"],
#    'PRODUCE_PIF' => "True",
#},
#

#------------------------------------------------------------------------------
# PLMNSUB: aggregate data for all PLMN IDs.  Mapped to HLR table, together with
# PLMNSUB (foreign PLMNs), HLRMAP, HLRSUBS, VLR, AUTHEN, ROAMING object types.
#{   
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_DESC' => 'Accumulate PLMNSUB (all PLMNs)',
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_BLOCK_NAME' => "PLMNHOME",
#    'INPUT_FILE_DESCRIPTION' => [ "PLMNSUB.*-#-I.pif" ],
#    'COUNTERS_TO_SORT_ON' => ["NODEID"],
#    'NON_ADDITIVE_COUNTERS' => ["OBJ_ID"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID",
#        "NO_OBJ_RECORDS","NO_COUNTERS", "OBJ_TYPE_FAULT_CODE"
#    ],
#},

#------------------------------------------------------------------------------
# VLR
#{   
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_DESC' => 'Accumulate IN',
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_BLOCK_NAME' => "VLRSUM",
#    'INPUT_FILE_DESCRIPTION' => [ "VLR.*-#-I.pif" ],
#    'COUNTERS_TO_SORT_ON' => ["NODEID"],
#    'NON_ADDITIVE_COUNTERS' => ["OBJ_ID"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID", "OBJ_GROUP_NO", "OBJ_TYPE_ID", "NO_OBJ_RECORDS",
#        "NO_COUNTERS", "OBJ_TYPE_FAULT_CODE"
#    ],
#},

#------------------------------------------------------------------------------
# Group PLMNSUB (including HOME), PLMNSUB (foreign), AUTHEN, VLR,
# HLRMAP, HLRSUBS
#
# NB/ 4/7/00
# The VLR files have been left out of this for the moment due to incorrect data
# The line that has been taken out is  "VLR-#-(.*)-#-I-#-VLRSUM-#-A.pif",
# this can be re-added at a later date
#
#{
#    'RULE_TYPE' => 'JOIN',
#    'INPUT_FILE_DESCRIPTION' => [
#        "PLMNSUB-#-(.*)-#-.+-#-I-#-PLMNHOME-#-A.pif",
#        "PLMNSUB-#-(.*)-#-.+-#-I-#-REMOVED-#-DW-#-PLMNNOHOME-#-A.pif",
#        "AUTHEN-#-(.*)-#-.+-#-I.pif",
#        "HLRMAP-#-(.*)-#-.+-#-I-#-HLRMAP-#-A.pif",
#        "VLR-#-(.*)-#-.+-#-I-#-VLRSUM-#-A.pif",
#        # R12 - Not required
#        #"HLRSUBS-#-(.*)-#-.+-#-I.pif",
#        #"ROAMING-#-(.*)-#-.+-#-I.pif"
#    ],
#    'OUTPUT_BLOCK_NAME' => "HLR",
#    'COUNTERS_TO_JOIN_ON' => ["NODEID"],
#    'OUTPUT_FILENAME_START' => "HLR_NSS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "START_TIME", "START_DATE"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
#    'PRODUCE_PIF' =>  0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

#------------------------------------------------------------------------------
# EOS (CC table)
#{
#    'RULE_TYPE' => 'DATALINE_WHERE',
#    'RULE_DESC' => "REMOVE ZERO COMPLETIONS",
#    'INPUT_FILE_DESCRIPTION' => [ "EOS-#-.*-#-I.pif" ],
#    'COUNTER_NAMES'  => [
#        {
#            'COUNTER_NAME'  => 'NEVERY',
#            'REMOVE_WHERE' => ["0"],
#        },
#    ],
#    'PRODUCE_PIF' => "True",
#    'FILENAME_ADDITION' => 'NO_ZERO',
#},

# Output EOS data to NSS directory
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson 9.0",
    'INPUT_FILE_DESCRIPTION' => [ "EOS-#-.*-#-I.pif" ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

#############################################################################
#   The configuration rules for the GPRS measurement objects starts here    #
#############################################################################

# R12 - Not required
# R8.0 GPRS BSCGPRS, LOADREG, LOASMISC and BSCQOS joined together
#{
#    'RULE_TYPE' => 'JOIN',
#    'RULE_DESC' => "Join the BSCGPRS, LOASMISC, LOADREG and BSCQOS counters",
#    'INPUT_FILE_DESCRIPTION' => [
#        "LOADREG(.*)-#-.+-#-I.pif",
#        "BSCGPRS(.*)-#-.+-#-I.pif",
#        "LOASMISC(.*)-#-.+-#-I.pif",
#        "BSCQOS(.*)-#-.+-#-I.pif"
#    ],
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_BLOCK_NAME' => "BSCGPRS",
#    'COUNTERS_TO_JOIN_ON' => ["NODEID"],
#    'OUTPUT_FILENAME_START' => "BSCGPRS",
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        "NODEID", "START_DATE","START_TIME"
#    ],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID","NO_OBJ_RECORDS","OBJ_TYPE_ID","NO_COUNTERS"
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -0.5,
#},

# R9.0 GPRS CELLGPRS & TRAFFGPRS joined together
{
    'RULE_TYPE' => 'JOIN',
    'RULE_DESC' => "Join the CELLGPRS and TRAFFGPRS counters",
    'INPUT_FILE_DESCRIPTION' => [
        "CELLGPRS(.*)-#-.+#-I.pif",
        "TRAFFGPRS(.*)-#-.+#-I.pif"
    ],
    'PRODUCE_PIF' => "TRUE",
    'OUTPUT_BLOCK_NAME' => "CELLGPRS",
    'COUNTERS_TO_JOIN_ON' => ["OBJ_ID"],
    'OUTPUT_FILENAME_START' => "CELLGPRS",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "START_DATE","START_TIME"
    ],
    'REDUNDANT_DATA_COUNTERS' => ["NO_OBJ_RECORDS","OBJ_TYPE_ID","NO_COUNTERS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -0.5,
},

# R9.0 GPRS RLINKBITR & TRAFFGPRS joined together
{
    'RULE_TYPE' => 'JOIN',
    'RULE_DESC' => "Join the RLINKBITR and TRAFFGPRS counters",
    'INPUT_FILE_DESCRIPTION' => [
        "TRAFFGPRS(.*)-#-.+#-I.pif",
        "RLINKBITR(.*)-#-.+#-I.pif"
    ],
    'PRODUCE_PIF' => "TRUE",
    'OUTPUT_BLOCK_NAME' => "RLINKBITR",
    'COUNTERS_TO_JOIN_ON' => ["OBJ_ID"],
    'OUTPUT_FILENAME_START' => "RLINKBITR",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "START_DATE","START_TIME"
    ],
    'REDUNDANT_DATA_COUNTERS' => ["NO_OBJ_RECORDS","OBJ_TYPE_ID","NO_COUNTERS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -0.5,
},

# R12 - Not required
# R8.0 GPRS BSCGPRS pif to lif
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "BSCGPRS counters",
#    'INPUT_FILE_DESCRIPTION' => [ "BSCGPRS(.*)#-J.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID","NO_OBJ_RECORDS","OBJ_TYPE_ID",
#        "OBJ_GROUP_NO","OBJ_TYPE_FAULT_CODE","NO_COUNTERS"
#    ],
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R12 - Rules for producing the EMGPRS block are not required
# CM 06/02/02 EMGPRS files have blank OBJ_IDs => must be filtered out
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Filter EMGPRS counters",
#    'INPUT_FILE_DESCRIPTION' => [ "EMGPRS(.*)#-I.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID","NO_OBJ_RECORDS","OBJ_TYPE_ID",
#        "OBJ_GROUP_NO","OBJ_TYPE_FAULT_CODE","NO_COUNTERS"
#    ],
#    'PRODUCE_PIF' => "True",
#},

# R8.0 GPRS BSCGPRS & PCU_LLC Merge 
#{
#    'RULE_TYPE' => 'JOIN',
#    'RULE_DESC' => "Join the BSCGPRS and EMGPRS counters",
#    'INPUT_FILE_DESCRIPTION' => [
#        "EMGPRS(.*)-#-.+#-0-#-I-#-P.pif",
#        "BSCGPRS(.*)-#-.+#-J.pif"
#    ],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "OBJ_ID","NO_OBJ_RECORDS","OBJ_TYPE_ID",
#        "OBJ_GROUP_NO","OBJ_TYPE_FAULT_CODE", "NO_COUNTERS","FILLER"
#    ],
#    'PRODUCE_PIF' => "True",
#    'OUTPUT_BLOCK_NAME' => 'EMGPRS',
#    'COUNTERS_TO_JOIN_ON' => ['NODEID'],
#    'OUTPUT_FILENAME_START' => 'EMGPRS',
#    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
#        'NODEID','START_DATE', 'START_TIME'
#    ],
#    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -0.5,
#},

# R8.0 GPRS EMGPRS pif to lif
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "EMGPRS counters",
#    'INPUT_FILE_DESCRIPTION' => [ "EMGPRS(.*)#-J.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
#        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS"
#    ],
#    'PRODUCE_PIF' => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R8.0 GPRS CELLGPRS
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "CELLGPRS counters",
    'INPUT_FILE_DESCRIPTION' => [ "CELLGPRS(.*)#-J.pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R9.0 GPRS TRAFFGPRS
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "TRAFFGPRS counters",
#    'INPUT_FILE_DESCRIPTION' => [ "TRAFFGPRS.*.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
#        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
#    ],
#    'PRODUCE_PIF' => "0",
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R9.0 GPRS BSCQOS
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "BSCQOS counters",
#    'INPUT_FILE_DESCRIPTION' => [ "BSCQOS.*.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
#        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
#    ],
#    'PRODUCE_PIF' => "0",
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R9.0 GPRS RLINKBITR
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "RLINKBITR counters",
    'INPUT_FILE_DESCRIPTION' => [ "RLINKBITR(.*)#-J.pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF' => "0",
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R9.0 GPRS CELLQOSG
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "CELLQOSG counters",
    'INPUT_FILE_DESCRIPTION' => [ "CELLQOSG.*.pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF' => "0",
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R8.0 for GPRS Statistics for GPRSGS & SGSNSTAT
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson GPRSGS NSS raw counters ",
    'INPUT_FILE_DESCRIPTION' => [ "GPRSGS(.*).pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO", 
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER","OBJ_ID"
    ],
    'PRODUCE_PIF'   => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R8.0 for GPRS Statistics for SGSNSTAT
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson SGSNSTAT NSS raw counters ",
    'INPUT_FILE_DESCRIPTION' => [ "SGSNSTAT(.*).pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER","OBJ_ID"
    ],
    'PRODUCE_PIF'   => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

## R8.0 for GPRS Statistics for SGSN
#{
#    'RULE_TYPE' => 'PIF_2_OUTPUT',
#    'RULE_DESC' => "Ericsson SGSN NSS raw counters ",
#    'INPUT_FILE_DESCRIPTION' => ["SGSN.*-#-I.pif"],
#    'REDUNDANT_DATA_COUNTERS' => [
#        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
#        " OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER","OBJ_ID"
#    ],
#    'PRODUCE_PIF'   => 0,
#    'OUTPUT_FORMAT' => 'LIF_Writer',
#},

# R8.0 for GPRS Statistics for SGSN
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson SGSN NSS raw counters ",
    'INPUT_FILE_DESCRIPTION' => [ "SGSN.*-#-I.pif"],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF'   => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# GPRS HLR_EGPR Stats
{
    'RULE_TYPE' => 'JOIN',
    'RULE_DESC' => "Join PLMNSUB, NAMSUBS and PDPDEF",
    'INPUT_FILE_DESCRIPTION' => [
        "PLMNSUB-#-(.*)-#-.+-#-I-#-PLMNHOME-#-A.pif",
        "PLMNSUB-#-(.*)-#-.+-#-I-#-REMOVED-#-DW-#-PLMNNOHOME-#-A.pif",
        "NAMSUBS-#-(.*)-#-.+-#-I.pif",
        "PDPDEF-#-(.*)-#-.+-#-I.pif"
    ],
    'OUTPUT_BLOCK_NAME' => "HLR_EGPR",
    'COUNTERS_TO_JOIN_ON' => ['NODEID'],
    'OUTPUT_FILENAME_START' => "HLR_EGPR",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "START_DATE", "START_TIME"
    ],
    'NON_APPLICALE_HEADER_COUNTERS' => [
        "OBJ_TYPE_ID","FILLER", "FILLER", 
        "FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
    ],
    'REDUNDANT_DATA_COUNTERS' => [
        "OBJ_TYPE_FAULT_CODE", "OBJ_GROUP_NO", "OBJ_ID",
        "OBJ_TYPE_ID", "NO_COUNTERS", "NO_OBJ_RECORDS",
        "NO_HPLMN_NUM_IN_SUM", "PERPLMNCNT_ALL",
        "PERPLMNCNT_NOHPLMN", "ALL_PLMN_NUM_IN_SUM"
    ],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => 1,
    'PRODUCE_PIF' => "True",
},

# Output HLR_EGPR data to NSS directory
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson 8.0 HLR_EGPR",
    'INPUT_FILE_DESCRIPTION' => [ "HLR_EGPR.*.pif" ],
    'PRODUCE_PIF' =>  0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => [
        "NODEID", "START_TIME", "START_DATE"
    ],
    'NON_APPLICABLE_HEADER_COUNTERS' => [
        "OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"
    ],
    'REDUNDANT_DATA_COUNTERS' => [
        "OBJ_ID" , "NODEID", "FILLER", "NO_COUNTERS" , "NO_OBJ_RECORDS"
    ],
},

# R9.0 Various GSM measurements to LIF file
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "R9 GSM counters",
    'INPUT_FILE_DESCRIPTION' => [
        "ATERTRANS.*.pif",
        "TRAPCOM.*.pif",
        "TRAPEVENT.*.pif",
        "TRASEVENT.*.pif",
        "NUCELLREL.*.pif"
    ],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF' => "0",
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# 2006-02-28 New rules
#------------------------------------------------------------------------------
# As there's no raw data to confirm the following,
# the approach will be a best guess solution of PIF_2_OUTPUT for the following:
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "No raw data, hence best guess will be pif_2_lif rule for these blocks",
    'INPUT_FILE_DESCRIPTION' => [
        "AUCSUBS-#-(.*)-#-.+-#-I.pif",
        #"C7ADJSLP-#-(.*)-#-.+-#-I.pif", 
        "AUTHSUBS-#-(.*)-#-.+-#-I.pif",
        #"CUGBSG-#-(.*)-#-.+-#-I.pif",
        "GSCF-#-(.*)-#-.+-#-I.pif",
        "HLRPERF-#-(.*)-#-.+-#-I.pif",
        "ODBINV-#-(.*)-#-.+-#-I.pif",
        "SDFINAP-#-(.*)-#-.+-#-I.pif",
        #"SERVFEAT-#-(.*)-#-.+-#-I.pif",
        "SPSP-#-(.*)-#-.+-#-I.pif",
        "SS7LS-#-(.*)-#-.+-#-I.pif",
        "SSACT-#-(.*)-#-.+-#-I.pif",
        "SSSPROC-#-(.*)-#-.+-#-I.pif",
        "TRAFFSRF-#-(.*)-#-.+-#-I.pif",
    ],
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS","OBJ_TYPE_ID","OBJ_GROUP_NO",
        "OBJ_TYPE_FAULT_CODE","NO_COUNTERS","FILLER"
    ],
    'PRODUCE_PIF'   => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# Additional Rules for Ericsson R11
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R11",
    'INPUT_FILE_DESCRIPTION' => [
        "CELLSTAT-#-(.*)-#-.+-#-I.pif",
        "AALSERV-#-(.*)-#-.+-#-I.pif",
        #"PAGING-#-(.*)-#-.+-#-I.pif",
        "UPDLOCAT-#-(.*)-#-.+-#-I.pif",
        "HLRSTAT-#-(.*)-#-.+-#-I.pif",
        "HLRSUBS-#-(.*)-#-.+-#-I.pif",
        "HNDOVER-#-(.*)-#-.+-#-I.pif",
        #"UGHNDOVER-#-(.*)-#-.+-#-I.pif", 
        #"GUHNDOVER-#-(.*)-#-.+-#-I.pif", 
        "ROAMING-#-(.*)-#-.+-#-I.pif",
        "C7SL1-#-(.*)-#-.+-#-I.pif",
        "C7SL2-#-(.*)-#-.+-#-I.pif",
        "C7SCQOS-#-(.*)-#-.+-#-I.pif",
        "C7SCPERF-#-(.*)-#-.+-#-I.pif",
#       Added based on SRS 38404
        "SECHAND-#-(.*)-#-.+-#-S.pif", 
#       Added this because it is found in the UserConfig.pm (SRS 38404)
        "ECPOOL-#-(.*)-#-.+-#-S.pif",
#       Added based on SRS 38407
        "EQIDCON-#-(.*)-#-.+-#-S.pif"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# Pif available, added pif_2_lif rules (bug no : 56415) 
{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R11",
    'INPUT_FILE_DESCRIPTION' => [
        "CSRROUTE-#-(.*)-#-.+-#-I.pif",
        "DIGPATH-#-(.*)-#-.+-#-I.pif",
        "DIP-#-(.*)-#-.+-#-I.pif",
        "EQIDCON-#-(.*)-#-.+-#-I.pif",
        "KRROUTE-#-(.*)-#-.+-#-I.pif",
        #"TRUNKROUT2-#-(.*)-#-.+-#-I.pif",
        "SMSGMSC-#-(.*)-#-.+-#-I.pif",
        "SMSGMSC-#-(.*)-#-.+-#-I.pif",
        "SMSIWMSC-#-(.*)-#-.+-#-I.pif",
        "SUPPLSERV-#-(.*)-#-.+-#-I.pif",
        #"TCABO-#-(.*)-#-.+-#-I.pif",
        "SCTPAM-#-(.*)-#-.+-#-I.pif",
        "SCTPLM-#-(.*)-#-.+-#-I.pif",
        "SECHAND-#-(.*)-#-.+-#-I.pif",
        "M3ASPSM-#-(.*)-#-.+-#-I.pif",
        "M3ASPTM-#-(.*)-#-.+-#-I.pif",
        "M3ASSOC-#-(.*)-#-.+-#-I.pif",
        "M3DATA-#-(.*)-#-.+-#-I.pif",
        "M3DEST1-#-(.*)-#-.+-#-I.pif",
        "M3MGMT-#-(.*)-#-.+-#-I.pif",
        "M3PERF-#-(.*)-#-.+-#-I.pif",
        "M3SSNM-#-(.*)-#-.+-#-I.pif",
        #"NAMSUBS-#-(.*)-#-.+-#-I.pif", 
        #"MBASTRAFTY-#-(.*)-#-.+-#-I.pif", 
        "SHSCF-#-(.*)-#-.+-#-I.pif",
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

# R12 new requirement
{ 
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_DESC' => "Accumulate TRAFFTYPE1",
    'INPUT_FILE_DESCRIPTION' => [ "TRAFFTYPE1-#-(.*)-#-I.pif" ],
    'COUNTERS_TO_SORT_ON' => [
        "NODEID", "START_DATE", "START_TIME"
    ],
    'NON_ADDITIVE_COUNTERS' => [ "OBJ_ID" ],
    'OUTPUT_BLOCK_NAME' => "TRAFFTYPE1_AGGR",
    #'APPEND_STR' => "_ALL",
    'REDUNDANT_DATA_COUNTERS' => [
        "NO_OBJ_RECORDS", "OBJ_TYPE_ID", "OBJ_GROUP_NO", "OBJ_TYPE_FAULT_CODE",
        "NO_COUNTERS", "FILLER", "OBJ_ID"
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R12",
    'INPUT_FILE_DESCRIPTION' => [
        '^GCPHRP-#-.*-#-I\.pif$',
        '^DEFMGW-#-.*-#-I\.pif$',
        '^GCPHQ-#-.*-#-I\.pif$',
        '^NRTCAP-#-.*-#-I\.pif$',
        '^NRTCFASERV-#-.*-#-I\.pif$',
        '^OOBTCSTAT-#-.*-#-I\.pif$',
        '^UPDLOCAT2-#-.*-#-I\.pif$',
        '^NBRMSCSRNS-#-.*-#-I\.pif$',
        '^PMROUTE-#-.*-#-I\.pif$',
        '^TQROUTE-#-.*-#-I\.pif$',
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R11 Missing Blocks from previous release",
    'INPUT_FILE_DESCRIPTION' => [
        '^MBASTRAFTY-#-.*-#-I\.pif$',
        '^BASTRAFTY1-#-.*-#-I\.pif$',
        '^MTRAFTYPE-#-.*-#-I\.pif$',
        '^JUNCTROUTE-#-.*-#-I\.pif$',
        '^TRUNKROUT2-#-.*-#-I\.pif$',
        '^TRUNKSUP-#-.*-#-I\.pif$',
        '^RESTART-#-.*-#-I\.pif$',
        '^TMSWITCH-#-.*-#-I\.pif$',
        '^NETWSYNC-#-.*-#-I\.pif$',
        '^RP-#-.*-#-I\.pif$',
        '^SS7TOTAL-#-.*-#-I\.pif$',
        '^C7MESS-#-.*-#-I\.pif$',
        '^PAGING-#-.*-#-I\.pif$',
        '^TCUSE-#-.*-#-I\.pif$',
        '^MRVTOT-#-.*-#-I\.pif$',
        '^CVTR02-#-.*-#-I\.pif$',
        '^LNPMAINT-#-.*-#-I\.pif$',
        '^LSCC-#-.*-#-I\.pif$',
        '^MNPMAINT-#-.*-#-I\.pif$',
        '^SHAM1-#-.*-#-I\.pif$',
        '^PRBTCALL-#-.*-#-I\.pif$',
        '^EM-#-.*-#-I\.pif$',
        '^EMG-#-.*-#-I\.pif$',
        '^EMRP-#-.*-#-I\.pif$',
        '^L2STATBA-#-.*-#-I\.pif$',
        '^L3STATBA-#-.*-#-I\.pif$',
        '^TPLAT -#-.*-#-I\.pif$',
        '^C7ODS-#-.*-#-I\.pif$',
        '^C7ODS24-#-.*-#-I\.pif$',
        '^MRVFAIL-#-.*-#-I\.pif$',
        '^SUBLINES-#-.*-#-I\.pif$',
        '^DIPSEC-#-.*-#-I\.pif$',
        '^L2STATPRA-#-.*-#-I\.pif$',
        '^L3STATPRA-#-.*-#-I\.pif$',
        '^CALLFSERV-#-.*-#-I\.pif$',
        '^CAWSERV-#-.*-#-I\.pif$',
        '^CKWSERV-#-.*-#-I\.pif$',
        '^CLIPSERV-#-.*-#-I\.pif$',
        '^CLIRSERV-#-.*-#-I\.pif$',
        '^COLPSERV-#-.*-#-I\.pif$',
        '^COLRSERV-#-.*-#-I\.pif$',
        '^CUGSERV-#-.*-#-I\.pif$',
        '^UUSSERV-#-.*-#-I\.pif$',
        '^COMPSERV-#-.*-#-I\.pif$',
        '^VPNSERV-#-.*-#-I\.pif$',
        '^ISDNEBS-#-.*-#-I\.pif$',
        '^FHLPRA-#-.*-#-I\.pif$',
        '^FHLV5-#-.*-#-I\.pif$',
        '^TTRMSN-#-.*-#-I\.pif$',
        '^USRACCESS-#-.*-#-I\.pif$',
        '^SDIPMS-#-.*-#-I\.pif$',
        '^SDIPHP-#-.*-#-I\.pif$',
        '^SDIPLP-#-.*-#-I\.pif$',
        '^L2V5CPATH-#-.*-#-I\.pif$',
        '^L2V5PRA-#-.*-#-I\.pif$',
        '^L3V5PRA-#-.*-#-I\.pif$',
        '^APPLATFORM-#-.*-#-I\.pif$',
        '^NAMSUBS-#-.*-#-I\.pif$',
        '^MESSFLNO-#-.*-#-I\.pif$',
        '^LOASMISC-#-.*-#-I\.pif$',
        '^LOASINCO-#-.*-#-I\.pif$',
        '^TCREJ-#-.*-#-I\.pif$',
        '^TCDIA-#-.*-#-I\.pif$',
        '^TCMSG-#-.*-#-I\.pif$',
        '^TCCMP-#-.*-#-I\.pif$',
        '^TCABO-#-.*-#-I\.pif$',
        '^SNT-#-.*-#-I\.pif$',
        '^SEQS_TRUNK-#-.*-#-I\.pif$',
        # Bug #56469 - Additional missing blocks
        '^BSCSTAT2-#-.*-#-I\.pif$',
        '^C7LSSI-#-.*-#-I\.pif$',
        '^C7OD-#-.*-#-I\.pif$',
        '^C7OPCDS-#-.*-#-I\.pif$',
        '^C7SIO-#-.*-#-I\.pif$',
        '^CAMELSMSCNT-#-.*-#-I\.pif$',
        '^DIPPRM-#-.*-#-I\.pif$',
        '^GORC-#-.*-#-I\.pif$',
        '^IRNEG-#-.*-#-I\.pif$',
        '^LATASTAT-#-.*-#-I\.pif$',
        '^LCSSTAT-#-.*-#-I\.pif$',
        '^M3DEST2-#-.*-#-I\.pif$',
        '^NBRCELLST-#-.*-#-I\.pif$',
        '^SS7HSLMT1-#-.*-#-I\.pif$',
        '^SS7HSLMT2-#-.*-#-I\.pif$',
        '^SS7HSLMT3-#-.*-#-I\.pif$',
        '^SS7HSLS-#-.*-#-I\.pif$',
        '^SS7HSLTRA-#-.*-#-I\.pif$',
        '^SS7SLMT1-#-.*-#-I\.pif$',
        '^SS7SLMT2-#-.*-#-I\.pif$',
        '^SS7SLTRAFF-#-.*-#-I\.pif$',
        '^SS7TT-#-.*-#-I\.pif$',
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

{
    'RULE_TYPE' => 'PIF_2_OUTPUT',
    'RULE_DESC' => "Ericsson R11 Additional Counters",
    'INPUT_FILE_DESCRIPTION' => [
        'ALLSERV-#-.*-#-I\.pif$',
        'ALTSERVICE-#-.*-#-I\.pif$',
        'ANSIGSMNM-#-.*-#-I\.pif$',
        'ATIPROP-#-.*-#-I\.pif$',
        'AUCMAP-#-.*-#-I\.pif$',
        'C7RTTOTAL-#-.*-#-I\.pif$',
        'C7SCCPUSE-#-.*-#-I\.pif$',
        'C7SCSIGP-#-.*-#-I\.pif$',
        'C7SCSUBSYS-#-.*-#-I\.pif$',
        'C7SLSET-#-.*-#-I\.pif$',
        #'CAMABT-#-.*-#-I\.pif$',
        'CAMEL3-#-.*-#-I\.pif$',
        'CODERASGN-#-.*-#-I\.pif$',
        'COPRVLRST-#-.*-#-I\.pif$',
        'CP-#-.*-#-I\.pif$',
        '^DATA-#-.*-#-I\.pif$',
        'DIGS-#-.*-#-I\.pif$',
        'DISCCALL-#-.*-#-I\.pif$',
        'DTAPLCS-#-.*-#-I\.pif$',
	#'EQLACC-#-.*-#-I\.pif$',
	#'FNRMAP-#-.*-#-I\.pif$',
        'GRPSWITCH-#-.*-#-I\.pif$',
        'HOLDSERV-#-.*-#-I\.pif$',
        'HS7SL1-#-.*-#-I\.pif$',
        'L3CCMSG-#-.*-#-I\.pif$',
        'LATAMISTAT-#-.*-#-I\.pif$',
        'LOAS-#-.*-#-I\.pif$',
        'MTSFB-#-.*-#-I\.pif$',
        'MTSFB3-#-.*-#-I\.pif$',
        'NBRMSCLST2-#-.*-#-I\.pif$',
        'NBRMSCLST3-#-.*-#-I\.pif$',
        'NSEPCALL-#-.*-#-I\.pif$',
        'ODB-#-.*-#-I\.pif$',
        'REGSERVICE-#-.*-#-I\.pif$',
        #'RESTART-#-.*-#-I\.pif$',
        # Bug valnt00003231
        # Remove SCTPTM pending sample data
        #'SCTPTM-#-.*-#-I\.pif$',
        'SESSSF-#-.*-#-I\.pif$',
        'SS7GWON-#-.*-#-I\.pif$',
        'SS7GWONTT-#-.*-#-I\.pif$',
        'SS7HSLPG1-#-.*-#-I\.pif$',
        'SS7HSLPG2-#-.*-#-I\.pif$',
        'SS7PRGRP-#-.*-#-I\.pif$',
        'SS7SCCPUSE-#-.*-#-I\.pif$',
        'SS7SCQOS-#-.*-#-I\.pif$',
        'SS7SCSUBSY-#-.*-#-I\.pif$',
        'SS7TIMERS-#-.*-#-I\.pif$',
        'SS7TOTAL2-#-.*-#-I\.pif$',
        'SSPSTAT2-#-.*-#-I\.pif$',
        'SUBDATA-#-.*-#-I\.pif$',
        'SUCORCL-#-.*-#-I\.pif$',
        'TPLAT-#-.*-#-I\.pif$',
        'TRAFFDEST1-#-.*-#-I\.pif$',
        # Not required. Produced in HLR
        #'AUTHEN-#-.*-#-I\.pif$',
    ],
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_DESC' => "Derive APPLATFORM counter from OBJ_ID for APDISKS blocks",
    'INPUT_FILE_DESCRIPTION' => ['^APDISKS-#-.*-#-I\.pif$'],
    'DATA_COUNTERS_OP' => sub {
        my $c_ref = shift;
        # Create new APPLATFORM counter
        # APPLATFORM is derived from OBJ_ID where OBJ_ID = <APPLATFORM>-<ID>.
        # The assumption is that the value of APPLATFORM is separated from
        # the ID by a '-'.
        # Example: OBJ_ID     = AP-1-F
        #          APPLATFORM = AP-1
        my $applatform = $c_ref->{OBJ_ID};
        my $ri = rindex($applatform, '-');
        $applatform = substr($applatform, 0, $ri) if $ri > -1;
        $c_ref->{APPLATFORM} = $applatform;

        # Output the data line
        return 0;
    },
    'FILENAME_SUFFIX' => 'PZ',
    'PRODUCE_PIF' => 0,
    'OUTPUT_FORMAT' => 'LIF_Writer',
},

);

#-------------------------------------------------------------------------------

sub postparser_config {
    return \@rules;
}


1;
